@@ -4,13 +4,14 @@ use warnings;
 use utf8;
 
 package Dist::Zilla::Plugin::MetaProvides::Class;
-$Dist::Zilla::Plugin::MetaProvides::Class::VERSION = '2.000000';
+
+our $VERSION = '2.001000';
+
 # ABSTRACT: Scans Dist::Zilla's .pm files and tries to identify classes using Class::Discover.
 
 our $AUTHORITY = 'cpan:KENTNL'; # AUTHORITY
 
 use Moose qw( has with );
-use Moose::Autobox;
 use Class::Discover ();
 
 use Dist::Zilla::MetaProvides::ProvideRecord 2.000000;
@@ -23,13 +24,6 @@ use Dist::Zilla::MetaProvides::ProvideRecord 2.000000;
 
 
 
-
-
-
-
-
-
-
 use namespace::autoclean;
 with 'Dist::Zilla::Role::MetaProvider::Provider';
 
@@ -79,9 +73,9 @@ sub provides {
     $self->_classes_for( $_->name, $_->content );
   };
 
-  my (@files) = $self->zilla->files->flatten;
+  my (@files) = @{ $self->zilla->files };
 
-  my (@records) = @files->grep($perl_module)->map($get_records)->flatten;
+  my (@records) = map { $get_records->()} grep {$perl_module->()} @files;
 
   return $self->_apply_meta_noindex(@records);
 }
@@ -105,9 +99,9 @@ sub _classes_for {
   };
   my $to_record = sub {
     Dist::Zilla::MetaProvides::ProvideRecord->new(
-      module  => $_->keys->at(0),
+      module  => [ keys %{$_} ]->[0],
       file    => $filename,
-      version => $_->values->at(0)->{version},
+      version => [ values %{$_} ]->[0]->{version},
       parent  => $self,
     );
   };
@@ -115,7 +109,7 @@ sub _classes_for {
   # I'm being bad and using a private function, but meh.
   # We know this is bad :(
   ## no critic ( ProtectPrivateSubs )
-  return [ Class::Discover->_search_for_classes_in_file( $scanparams, \$content ) ]->map($to_record)->flatten;
+  return map { $to_record->() }  Class::Discover->_search_for_classes_in_file( $scanparams, \$content );
 }
 
 
@@ -145,7 +139,7 @@ Dist::Zilla::Plugin::MetaProvides::Class - Scans Dist::Zilla's .pm files and tri
 
 =head1 VERSION
 
-version 2.000000
+version 2.001000
 
 =head1 SYNOPSIS
 
@@ -212,7 +206,7 @@ Kent Fredric <kentnl@cpan.org>
 
 =head1 COPYRIGHT AND LICENSE
 
-This software is copyright (c) 2014 by Kent Fredric.
+This software is copyright (c) 2014 by Kent Fredric <kentfredric@gmail.com>.
 
 This is free software; you can redistribute it and/or modify it under
 the same terms as the Perl 5 programming language system itself.
