@@ -10,8 +10,11 @@ use strict;
 use warnings;
 use utf8;
 
+our $VERSION = 0.001;
+
 use Carp qw( croak carp );
 use Perl::Critic::ProfileCompiler::Util qw( create_bundle );
+use Path::Tiny qw(path);
 
 ## no critic (ErrorHandling::RequireUseOfExceptions)
 my $bundle = create_bundle('Example::Author::KENTNL');
@@ -34,13 +37,16 @@ my $inf = $bundle->actionlist->get_inflated;
 my $config = $inf->apply_config;
 
 {
-  open my $rcfile, '>', './perlcritic.rc' or croak 'Cant open perlcritic.rc';
+  my $rcfile = path('./perlcritic.rc')->openw_utf8;
   $rcfile->print( $config->as_ini, "\n" );
   close $rcfile or croak 'Something fubared closing perlcritic.rc';
 }
 my $deps = $inf->own_deps;
 {
-  open my $depsfile, '>', './perlcritic.deps' or croak 'Cant open perlcritic.deps';
+  my $target = path('./misc');
+  $target->mkpath if not $target->is_dir;
+
+  my $depsfile = $target->child('perlcritic.deps')->openw_utf8;
   for my $key ( sort keys %{$deps} ) {
     $depsfile->printf( "%s~%s\n", $key, $deps->{$key} );
     *STDERR->printf( "%s => %s\n", $key, $deps->{$key} );
